
Data Types
==========

Automatically generated index page for Data Types:

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   bai
   bam
   bed
   bedgz
   bedtabix
   boolean
   compressedindexedvcf
   compressedtarfile
   compressedvcf
   crai
   cram
   crampair
   csv
   directory
   double
   fasta
   fastabwa
   fastafai
   fastagz
   fastagzbwa
   fastagzfai
   fastagzwithindexes
   fastawithindexes
   fastdict
   fastgzdict
   fastq
   fastqgz
   file
   filename
   float
   gzip
   htmlfile
   indexedbam
   indexedvcf
   integer
   jsonfile
   kallistoidx
   sam
   stdout
   string
   tarfile
   textfile
   tsv
   vcf
   whisperidx
   zip

*This page was auto-generated on 22/12/2020. Please do not directly alter the contents of this page.*
